@@ -780,7 +780,6 @@ brasero_status_dialog_uri_has_image (BraseroTrackDataCfg *track,
 {
 	gint answer;
 	gchar *name;
-	gchar *string;
 	GtkWidget *button;
 	GtkWidget *dialog;
 	gboolean was_visible = FALSE;
@@ -802,10 +801,11 @@ brasero_status_dialog_uri_has_image (BraseroTrackDataCfg *track,
 	                          gtk_window_get_icon_name (GTK_WINDOW (self)));
 
 	name = brasero_utils_get_uri_name (uri);
-	/* Translators: %s is the name of the image */
-	string = g_strdup_printf (_("There is only one selected file (\"%s\"). It is the image of a disc and its contents can be burned."), name);
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), string);
-	g_free (string);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			/* Translators: %s is the name of the image */
+			_("There is only one selected file (\"%s\"). "
+			  "It is the image of a disc and its contents can be burned."),
+			name);
 	g_free (name);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Burn as _File"), GTK_RESPONSE_NO);
@@ -1132,7 +1132,7 @@ brasero_burn_options_install_missing (BraseroPluginErrorType type,
 	int xid = 0;
 
 	/* Get the xid */
-	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (GTK_WIDGET (user_data)->window));
+	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (gtk_widget_get_window (GTK_WIDGET (user_data))));
 
 	package = brasero_pk_new ();
 	cancel = g_cancellable_new ();
